@@ -699,8 +699,12 @@ class Base(Controller):
                 # TODO: what if there's no forks to give?
                 "help" : "Github URL to search for forks."
             }),
-            (['-r','--remote'],{
-                "help" : "The remote to search for forks.",
+            (['--remote'],{
+                "help" : "Remove remote branches.",
+                "action" : "store"
+            }),
+            (['-r','--remove'],{
+                "help" : "Remove remote branches.",
                 "action" : "store"
             }),
         ]
@@ -723,7 +727,10 @@ class Base(Controller):
             
             if self.app.pargs.remote is None: remote = True
             else: remote = self.app.pargs.remote == 'True'
-            print(find_branches(self.app.pargs.url, remote))
+            
+            
+            remove = self.app.pargs.__dict__.get('remove', True)
+            print(find_branches(self.app.pargs.url, remote, remove))
             
     # create notes that are organized into project folders and are stored in md files
     @ex(
