@@ -4,7 +4,7 @@ import faker
 import pandas as pd
 import pyperclip
 import time
-
+import os
 
 def replicate_cliboard():
     # get the clipboard
@@ -136,10 +136,13 @@ def generate_fake_data(n_lines, template, delimiter,
     if primary_key=='-1':
         # generate a primary key
         df_fake['primary_key'] = [fake.uuid4() for i in range(df_fake.shape[0])]
-    
-    print(df_fake)
-    
+        
     # save as a csv with time
     if csv:
         timestamp = time.strftime("%Y%m%d-%H%M%S")
-        df_fake.to_csv(f'fake_data_{timestamp}.csv', index=False)
\ No newline at end of file
+        df_fake.to_csv(f'fake_data_{timestamp}.csv', index=False)
+        print(f"Saved full path: {os.getcwd()}/fake_data_{timestamp}.csv")
+        
+    else:
+        print(df_fake)
+        
\ No newline at end of file
